function [meshP, polygcl] = meshpolyg(deg,nsides)

%give the coordinates of successive vertices
%in clockwise or counterclockwise order
%regular polygon
j=(0:nsides-1)';
polyg=[cos(2*pi*j/nsides) sin(2*pi*j/nsides)];
center=[0 0];

%starlike polygon
%closing the boundary
polygcl=[polyg;polyg(1,1) polyg(1,2)];
mymesh=[ ];
for i=1:length(polyg(:,1))
  triangle=[polygcl(i,1) polygcl(i,2);
  polygcl(i+1,1) polygcl(i+1,2);center(1) center(2)];
  triangle=[polygcl(i,1) polygcl(i,2);center(1) center(2);
  polygcl(i+1,1) polygcl(i+1,2)];
%exctracting from a weakly-admissible mesh
mymesh=[mymesh;wamtriangle2(deg,triangle)];
end;

meshP=mymesh;

function meshT = wamtriangle2(deg,triangle);

%produces a weakly admissible mesh in a triangle

%INPUT:

%deg = interpolation degree

%triangle = 3 x 2 array of the vertices coordinates


%OUTPUT:

%meshT = 2-columns array of mesh points coordinates


%FUNCTION BODY

%producing a weakly-admissible mesh for even
%polynomials in the quadrant
n1=2*deg;
n2=n1;
j1=(0:1:deg);
j2=(0:1:deg);
[rho,theta]=meshgrid(cos(j1*pi/n1),j2*pi/n2);

%mapping to the simplex
B=[rho(:).*cos(theta(:)) rho(:).*sin(theta(:))];
meshS=[B(:,1).^2 B(:,2).^2];
meshT(:,1)=triangle(3,1)*(1-meshS(:,1)-meshS(:,2)) ...
    +triangle(2,1)*meshS(:,2)+triangle(1,1)*meshS(:,1);
meshT(:,2)=triangle(3,2)*(1-meshS(:,1)-meshS(:,2)) ...
    +triangle(2,2)*meshS(:,2)+triangle(1,2)*meshS(:,1);
