function M = wamcone(P,V,n,e)
%----------------------------------------
% inputs
% P: array of 2d mesh points
% V: vertex (3d point)
% n: polynomial degree
% e: elevation of the cut in percentage

% output
% M: 3d conical mesh
%
% by Stefano De Marchi and Marco Vianello, University of Padova 
% 
% January 2013
%----------------------------------------

% Chebyshev-Lobatto points in [0,1]*e
 cheb=0.5*e+0.5*e*cos([0:n]*pi/n);
 if (V(3)==-inf)
     cheb=-cheb;
 end
 M=[];
 Q=[P,zeros(size(P,1),1)];
 
 if (V(3)==inf | V(3)==-inf)
   
   for i=1:n+1
     Q1=repmat([0,0,cheb(i)],size(Q,1),1);
     M=[M;Q+Q1];
   end
 else
  V1=repmat(V,size(P,1),1);
  for i=1:n+1
    M=[M;Q+cheb(i)*(V1-Q)];
   end
 end

return

